homology.PersDiag.plot — GDA Toolbox v1.0 Manual

# homology.PersDiag.plot

`PersDiag.` `plot`(canvas, transform=None, bins=None, title='Pers Diag')

  Plot the persistence diagram using `matplotlib` or `bokeh`.

  Parameters: | canvas An instance of :class:`bokeh.plotting.figure.Figure` invoked as canvas = bokeh.plotting.figure(), or a an instance of `matplotlib.axes._subplots.AxesSubplot` invoked as fig,canvas = matplotlib.pyplot.subplots() or similar.

  Notes

  You have to save or show the canvas after running this call.

#### Previous topic

homology.PersDiag.grab

#### Next topic

homology.PersDiag.syzygy